@@ -85,11 +85,15 @@ class Container(object):
     del contents[index]
 
   def searchprocess(self, type, process):
+    "Search for elements of a given type and process them"
+    self.locateprocess(lambda container: isinstance(container, type), process)
+
+  def locateprocess(self, locate, process):
     "Search for all embedded containers and process them"
     for index, element in enumerate(self.contents):
       if isinstance(element, Container):
-        element.searchprocess(type, process)
-      if isinstance(element, type):
+        element.locateprocess(locate, process)
+      if locate(element):
         process(self.contents, index)
 
   def extracttext(self):
@@ -136,6 +140,18 @@ class Container(object):
       if isinstance(element, Container):
         element.debug(level + 1)
 
+  def parselstparams(self):
+    "Parse a multiple parameter lstparams."
+    if not 'lstparams' in self.parameters:
+      return
+    paramlist = self.parameters['lstparams'].split(',')
+    for param in paramlist:
+      if not '=' in param:
+        Trace.error('Invalid listing parameter ' + param)
+      else:
+        key, value = param.split('=', 1)
+        self.parameters[key] = value
+
   def __unicode__(self):
     "Get a description"
     if not hasattr(self, 'begin'):
