@@ -28,56 +28,25 @@ from gen.factory import *
 from gen.structure import *
 
 
-class TOCWriter(object):
-  "A class to write the TOC of a document."
+class TOCEntry(Container):
+  "A container for a TOC entry."
 
-  def __init__(self, writer):
-    self.writer = writer
+  ordered = NumberingConfig.layouts['ordered']
+  unique = NumberingConfig.layouts['unique']
+
+  def create(self, container):
+    "Create the TOC entry for a container, consisting of a single link."
+    text = TranslationConfig.constants[container.type] + ' ' + container.number
+    text += ':' + self.gettitle(container) + '\n'
+    url = Options.toctarget + '#toc-' + container.type + '-' + container.number
+    self.contents = [Link().complete(text, url=url)]
+    self.output = TaggedOutput().settag('div class="toc"', True)
     self.depth = 0
-    Options.nocopy = True
-
-  def clone(self, filterheader):
-    "Return a cloned copy."
-    clone = TOCWriter()
-    clone.writer = self.writer
-    return clone
-
-  def write(self, container):
-    "Write the table of contents for a container."
-    if container.__class__ in [LyxHeader, LyxFooter]:
-      self.writeheaderfooter(container)
-      return
-    if not hasattr(container, 'number'):
-      return
-    self.indent(container.type)
-    self.createlink(container.type, container.number, self.gettitle(container))
-
-  def createlink(self, type, number, title):
-    "Create the actual link for the TOC."
-    text = TranslationConfig.constants[type] + ' ' + number
-    text += ':' + title + '\n'
-    url = Options.toc + '#toc-' + type + '-' + number
-    link = Link().complete(text, url=url)
-    toc = TaggedText().complete([link], 'div class="toc"', True)
-    self.writer.write(toc.gethtml())
-
-  def indent(self, type):
-    "Indent the line according to the container type."
-    if type in NumberingConfig.layouts['unique']:
-      depth = 0
-    elif type in NumberingConfig.layouts['ordered']:
-      depth = NumberingConfig.layouts['ordered'].index(type) + 1
-    elif not type:
-      Trace.error('Empty type')
-      return
-    else:
-      Trace.error('Unknown numbered container type ' + type)
-      return
-    if depth > self.depth:
-      self.openindent(depth - self.depth)
-    elif depth < self.depth:
-      self.closeindent(self.depth - depth)
-    self.depth = depth
+    if container.type in TOCEntry.ordered:
+      self.depth = TOCEntry.ordered.index(container.type) + 1
+    elif not container.type in TOCEntry.unique:
+      Trace.error('Unknown numbered container type ' + container.type)
+    return self
 
   def gettitle(self, container):
     "Get the title of the container."
@@ -86,11 +55,20 @@ class TOCWriter(object):
     withoutlabel = TaggedText().complete(container.contents[1:], 'x')
     return withoutlabel.extracttext()
 
-  def writeheaderfooter(self, container):
-    "Write the header or the footer."
-    if isinstance(container, LyxFooter):
-      self.closeindent(self.depth)
-    self.writer.write(container.gethtml())
+class Indenter(object):
+  "Manages and writes indentation for the TOC."
+
+  def __init__(self, writer):
+    self.depth = 0
+    self.writer = writer
+
+  def indent(self, depth):
+    "Indent the line according to the given depth."
+    if depth > self.depth:
+      self.openindent(depth - self.depth)
+    elif depth < self.depth:
+      self.closeindent(self.depth - depth)
+    self.depth = depth
 
   def openindent(self, times):
     "Open the indenting div a few times."
