@@ -30,6 +30,7 @@ from util.options import *
 from gen.factory import *
 from gen.toc import *
 from gen.inset import *
+from gen.basket import *
 from post.postprocess import *
 from post.postlist import *
 from post.posttable import *
@@ -37,26 +38,30 @@ from math.postformula import *
 
 
 class eLyXerConverter(object):
-  "Converter for a document in a lyx file"
+  "Converter for a document in a lyx file. Places all output in a given basket."
 
-  latestwriter = None
+  latestbasket = None
 
   def setio(self, ioparser):
     "Set the InOutParser"
     self.reader = LineReader(ioparser.filein)
-    linewriter = LineWriter(ioparser.fileout)
+    self.writer = LineWriter(ioparser.fileout)
     if Options.toc:
-      self.writer = TOCWriter(linewriter)
+      self.basket = TOCBasket()
     else:
-      self.writer = ContainerWriter(linewriter)
-    eLyXerConverter.latestwriter = self.writer
+      if not Options.splitpart:
+        self.basket = WriterBasket()
+      else:
+        self.basket = SplittingBasket()
+    self.basket.setwriter(self.writer)
+    eLyXerConverter.latestbasket = self.basket
     return self
 
-  def embed(self, filein):
+  def embed(self, reader):
     "Embed the results for a new input file into the latest output file."
     "Header and footer are ignored. Useful for embedding one document inside another."
-    self.reader = LineReader(filein)
-    self.writer = eLyXerConverter.latestwriter.clone(filterheader = True)
+    self.reader = reader
+    self.basket = eLyXerConverter.latestbasket.getfilterheader()
     return self
 
   def convert(self):
@@ -75,35 +80,15 @@ class eLyXerConverter(object):
       containers = factory.createsome(self.reader)
       for container in containers:
         container = self.postproc.postprocess(container)
-        self.writer.write(container)
-
-class ContainerWriter(object):
-  "A writer of containers. Just writes them out to a line writer."
-
-  def __init__(self, linewriter):
-    self.linewriter = linewriter
-    self.filterheader = False
-
-  def clone(self, filterheader):
-    "Clone the writer."
-    clone = ContainerWriter(self.linewriter)
-    clone.filterheader = filterheader
-    return clone
-
-  def write(self, container):
-    "Write a container to the line writer."
-    if self.filterheader and container.__class__ in [LyxHeader, LyxFooter]:
-      return
-    self.linewriter.write(container.gethtml())
+        self.basket.write(container)
+    self.basket.finish()
 
 class InOutParser(object):
   "Parse in and out arguments"
 
   def __init__(self):
     self.filein = sys.stdin
-    self.parsedin = False
     self.fileout = sys.stdout
-    self.parsedout = False
 
   def parse(self, args):
     "Parse command line arguments"
@@ -114,22 +99,40 @@ class InOutParser(object):
     if len(args) > 0:
       self.filein = args[0]
       del args[0]
-      self.parsedin = True
+      self.readdir(self.filein, 'directory')
+    else:
+      Options.directory = '.'
     if len(args) > 0:
       self.fileout = args[0]
       del args[0]
-      self.parsedout = True
+      self.readdir(self.fileout, 'destdirectory')
+    else:
+      Options.destdirectory = '.'
     if len(args) > 0:
       raise Exception('Unused arguments: ' + unicode(args))
     return self
 
+  def readdir(self, filename, diroption):
+    "Read the current directory if needed"
+    if getattr(Options, diroption) != None:
+      return
+    setattr(Options, diroption, os.path.dirname(filename))
+    if getattr(Options, diroption) == '':
+      setattr(Options, diroption, '.')
+
 class ConverterFactory(object):
   "Create a converter fit for converting a filename and embedding the result."
 
-  def create(self, filename):
-    "Create a converter for a given filename."
-    fullname = os.path.join(Options.directory, filename)
-    return eLyXerConverter().embed(fullname)
+  def create(self, container):
+    "Create a converter for a given container, with filename"
+    " and possibly other parameters."
+    fullname = os.path.join(Options.directory, container.filename)
+    reader = LineReader(fullname)
+    if 'firstline' in container.parameters:
+      reader.setstart(int(container.parameters['firstline']))
+    if 'lastline' in container.parameters:
+      reader.setend(int(container.parameters['lastline']))
+    return eLyXerConverter().embed(reader)
 
 IncludeInset.converterfactory = ConverterFactory()
 
