@@ -23,6 +23,7 @@
 # eLyXer BibTeX processing
 
 from util.trace import Trace
+from util.clone import *
 from io.output import *
 from io.path import *
 from io.bulk import *
@@ -45,7 +46,7 @@ class BibTeX(Container):
     bibliography = TranslationConfig.constants['bibliography']
     tag = TaggedText().constant(bibliography, 'h1 class="biblio"')
     self.contents.append(tag)
-    files = self.parser.parameters['bibfiles'].split(',')
+    files = self.parameters['bibfiles'].split(',')
     for file in files:
       bibfile = BibFile(file)
       bibfile.parse()
@@ -66,7 +67,7 @@ class BibTeX(Container):
 
   def readstyle(self):
     "Read the style from the bibliography options"
-    options = self.parser.parameters['options'].split(',')
+    options = self.parameters['options'].split(',')
     for option in options:
       if hasattr(BibStylesConfig, option):
         return getattr(BibStylesConfig, option)
@@ -104,7 +105,7 @@ class BibFile(object):
     "Parse a single entry"
     for entry in Entry.entries:
       if entry.detect(pos):
-        newentry = entry.clone()
+        newentry = Cloner.clone(entry)
         newentry.parse(pos)
         if newentry.isreferenced():
           self.entries.append(newentry)
@@ -228,13 +229,6 @@ class Entry(Container):
     "Parse a piece not structure"
     return pos.glob(lambda current: not current in undesired)
 
-  def clone(self):
-    "Return an exact copy of self"
-    type = self.__class__
-    clone = type.__new__(type)
-    clone.__init__()
-    return clone
-
 class SpecialEntry(Entry):
   "A special entry"
 
