@@ -47,11 +47,12 @@ class Options(object):
   title = None
   directory = None
   destdirectory = None
-  toc = None
+  toc = False
+  toctarget = ''
   forceformat = None
   lyxformat = False
   target = None
-  cutpart = 1
+  splitpart = None
 
   branches = dict()
 
@@ -77,6 +78,15 @@ class Options(object):
       self.showversiondate()
     if Options.lyxformat:
       self.showlyxformat()
+    if Options.splitpart:
+      try:
+        Options.splitpart = int(Options.splitpart)
+        if Options.splitpart <= 0:
+          Trace.error('--splitpart a number bigger than zero')
+          self.usage()
+      except:
+        Trace.error('--splitpart needs a numeric argument, not ' + Options.splitpart)
+        self.usage()
     # set in Trace if necessary
     for param in dir(Options):
       if hasattr(Trace, param + 'mode'):
@@ -105,7 +115,7 @@ class Options(object):
     Trace.error('    --forceformat ".extension": force image output format')
     Trace.error('    --lyxformat:                return the highest LyX version that can be')
     Trace.error('                                converted')
-    Trace.error('    --toc "original.html":      create a TOC with links to the original')
+    Trace.error('    --toc:                      create a table of contents')
     Trace.error('    --target "frame":           make all links point to the given frame')
     exit()
 
